import{K as n,E as p,L as s}from"./repository.8d0efc43.js";import{d as a,b as m,c,u as e}from"./outputWidgets.0a8e4948.js";import{l as d}from"./index.14897ab9.js";import"./asyncComputed.059a4705.js";import"./api.08f5d047.js";import"./index.cf4c23b9.js";import"./icons.b13f0b09.js";import"./index.2673874d.js";import"./ant-design.efb76e31.js";import"./index.ab9ed469.js";import"./Modal.7e08920e.js";import"./Text.ec9c769b.js";import"./Base.dda5d58b.js";import"./Typography.fd999a5c.js";import"./index.e5d762a8.js";import"./index.b9c8498e.js";import"./Paragraph.b4aaf7da.js";import"./index.c3402215.js";import"./Link.6650ff19.js";import"./Title.ca8d43a3.js";import"./index.f4e17bed.js";import"./CollapsePanel.59258ae1.js";import"./Form.c559c050.js";import"./hasIn.8bcc6abb.js";import"./Timeline.bd3fc2e4.js";import"./index.6be6239e.js";import"./index.561d86d7.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.55cc010e.js";import"./workspaces.a90ffeac.js";import"./runnerData.e96f67ef.js";import"./url.5c05e609.js";import"./record.68d70ea4.js";import"./pubsub.dcb12b9f.js";import"./scripts.89e68ee2.js";import"./envVars.ef1bfd4f.js";import"./ExpandOutlined.ca400c9f.js";import"./Card.34fc0534.js";import"./TabPane.4ede097c.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="c65ce475-4c91-4c9b-80bd-bb621e79adf5",t._sentryDebugIdIdentifier="sentry-dbid-c65ce475-4c91-4c9b-80bd-bb621e79adf5")}catch{}})();class b{constructor(o=d){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const oo=a({__name:"WorkflowKanban",setup(t){const o=new p,r=new b,i=new s("kanban");return(f,u)=>(m(),c(n,{"kanban-repository":e(o),storage:e(i),"stage-run-repository":e(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{oo as default};
//# sourceMappingURL=WorkflowKanban.92de1773.js.map
