import{cz as d}from"./outputWidgets.0a8e4948.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="d540d1b0-0c28-4f99-991b-c31604281b06",e._sentryDebugIdIdentifier="sentry-dbid-d540d1b0-0c28-4f99-991b-c31604281b06")}catch{}})();const t=(e,r)=>{d.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.d7120f82.js.map
