import{_ as s}from"./Navbar.vue_vue_type_script_setup_true_lang.2f9ecb34.js";import{K as d,P as f,L as l}from"./repository.8d0efc43.js";import{d as b,b as u,ev as c,f as p,u as r}from"./outputWidgets.0a8e4948.js";import{u as g}from"./index.14897ab9.js";import{a as y}from"./asyncComputed.059a4705.js";import{g as _}from"./api.2af17107.js";import"./Text.ec9c769b.js";import"./Base.dda5d58b.js";import"./Typography.fd999a5c.js";import"./index.c3402215.js";import"./Link.6650ff19.js";import"./Paragraph.b4aaf7da.js";import"./Title.ca8d43a3.js";import"./index.3a967032.js";import"./ArrowRightOutlined.08fa31dd.js";import"./api.08f5d047.js";import"./index.cf4c23b9.js";import"./icons.b13f0b09.js";import"./index.2673874d.js";import"./ant-design.efb76e31.js";import"./index.ab9ed469.js";import"./Modal.7e08920e.js";import"./index.e5d762a8.js";import"./index.b9c8498e.js";import"./index.f4e17bed.js";import"./CollapsePanel.59258ae1.js";import"./Form.c559c050.js";import"./hasIn.8bcc6abb.js";import"./Timeline.bd3fc2e4.js";import"./index.6be6239e.js";import"./index.561d86d7.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.55cc010e.js";import"./workspaces.a90ffeac.js";import"./runnerData.e96f67ef.js";import"./url.5c05e609.js";import"./record.68d70ea4.js";import"./pubsub.dcb12b9f.js";import"./scripts.89e68ee2.js";import"./envVars.ef1bfd4f.js";import"./ExpandOutlined.ca400c9f.js";import"./Card.34fc0534.js";import"./TabPane.4ede097c.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="a563a426-80fb-43f6-8701-641560debd8e",o._sentryDebugIdIdentifier="sentry-dbid-a563a426-80fb-43f6-8701-641560debd8e")}catch{}})();const fo=b({__name:"Kanban",setup(o){const t=new f(g),a=new l("kanban"),{result:e}=y(_);return(k,w)=>{var i,n,m;return u(),c("div",null,[p(s,{"brand-name":((i=r(e))==null?void 0:i.brandName)||((n=r(e))==null?void 0:n.name),"logo-url":(m=r(e))==null?void 0:m.logoUrl},null,8,["brand-name","logo-url"]),p(d,{"kanban-repository":r(t),storage:r(a)},null,8,["kanban-repository","storage"])])}}});export{fo as default};
//# sourceMappingURL=Kanban.e5fe1f1f.js.map
