import{S as p}from"./Sidebar.3ca221d8.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.a9fd617c.js";import{L as d,M as l,N as u}from"./icons.b13f0b09.js";import{d as b,eB as f,H as g,a as _,b as y,c as v,w as a,f as r}from"./outputWidgets.0a8e4948.js";import{a as w}from"./asyncComputed.059a4705.js";import"./router.a730a2c1.js";import"./index.fea4a6f4.js";import{O as z}from"./organization.9a1833bb.js";import{B as h}from"./BaseLayout.41f796b7.js";import"./index.e5d762a8.js";import"./logo.084e5d7c.js";import"./Text.ec9c769b.js";import"./Base.dda5d58b.js";import"./Typography.fd999a5c.js";import"./index.3a967032.js";import"./ArrowRightOutlined.08fa31dd.js";import"./Form.c559c050.js";import"./hasIn.8bcc6abb.js";import"./index.cf4c23b9.js";import"./record.68d70ea4.js";import"./pubsub.dcb12b9f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="fa128611-b1ce-42e0-9bfe-6c8ed5e1021e",e._sentryDebugIdIdentifier="sentry-dbid-fa128611-b1ce-42e0-9bfe-6c8ed5e1021e")}catch{}})();const K=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:t}=w(()=>z.get(n)),i=g(()=>t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.name,path:`/organizations/${t.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:a(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:a(()=>[r(p,{class:"sidebar",sections:s})]),content:a(()=>[r(m)]),_:1})}}});export{K as default};
//# sourceMappingURL=Organization.09f6bf60.js.map
