import{e8 as p,ac as d,V as s,f,Q as b}from"./outputWidgets.0a8e4948.js";import{B as y,b as u}from"./Base.dda5d58b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="5bdee8a7-303e-4381-96a5-4cc466b0867d",e._sentryDebugIdIdentifier="sentry-dbid-5bdee8a7-303e-4381-96a5-4cc466b0867d")}catch{}})();var g=globalThis&&globalThis.__rest||function(e,o){var n={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&o.indexOf(t)<0&&(n[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var r=0,t=Object.getOwnPropertySymbols(e);r<t.length;r++)o.indexOf(t[r])<0&&Object.prototype.propertyIsEnumerable.call(e,t[r])&&(n[t[r]]=e[t[r]]);return n};const m=p(1,2,3,4,5),_=()=>s(s({},b(u(),["component","strong"])),{level:Number}),l=(e,o)=>{let{slots:n,attrs:t}=o;const{level:r=1}=e,i=g(e,["level"]);let a;m.includes(r)?a=`h${r}`:(d(),a="h1");const c=s(s(s({},i),{component:a}),t);return f(y,c,n)};l.displayName="ATypographyTitle";l.inheritAttrs=!1;l.props=_();const w=l;export{w as A};
//# sourceMappingURL=Title.ca8d43a3.js.map
