import{v as o,a as r,b as i,c,j as p,T as d,k as f,P as _,C as u,M as l,s as g,l as s,m as b,n as m,p as y,q as v}from"./outputWidgets.0a8e4948.js";import{s as w,a}from"./index.14897ab9.js";import"./pubsub.dcb12b9f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9a3b820a-fb86-423f-950e-704ea5af9705",e._sentryDebugIdIdentifier="sentry-dbid-9a3b820a-fb86-423f-950e-704ea5af9705")}catch{}})();const h={};function I(e,t){const n=r("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const k=o(h,[["render",I]]);class x{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const e=p({render:()=>b(k)});d.init(),f(e,a),x.init(),e.use(a),e.use(_),e.mount("#app"),e.component("VSelect",u),e.component("Markdown",l),e.component("Message",g),s(e,m),s(e,y),s(e,v)})();
//# sourceMappingURL=player.09d378d6.js.map
