import{v as t,b as s,ev as o}from"./outputWidgets.0a8e4948.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="7762f9c5-73de-48e8-bb8e-cc6beb46a887",e._sentryDebugIdIdentifier="sentry-dbid-7762f9c5-73de-48e8-bb8e-cc6beb46a887")}catch{}})();const r={},c={class:"organization-settings"};function i(e,n){return s(),o("div",c,"Organization settings")}const f=t(r,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.4743954a.js.map
