import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.2f9ecb34.js";import{g as f}from"./api.2af17107.js";import{a as _}from"./asyncComputed.059a4705.js";import{W as y}from"./WidgetsFrame.64d79499.js";import{d as g,eB as b,b as n,ev as h,e as a,u as t,c as d,w as v,ex as l,eD as u,v as w}from"./outputWidgets.0a8e4948.js";import"./index.14897ab9.js";import"./pubsub.dcb12b9f.js";import"./Text.ec9c769b.js";import"./Base.dda5d58b.js";import"./Typography.fd999a5c.js";import"./index.c3402215.js";import"./Link.6650ff19.js";import"./Paragraph.b4aaf7da.js";import"./Title.ca8d43a3.js";import"./index.3a967032.js";import"./ArrowRightOutlined.08fa31dd.js";import"./runnerData.e96f67ef.js";import"./url.5c05e609.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new D().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="42037045-38c2-4971-95b3-1c6caa2fdedc",o._sentryDebugIdIdentifier="sentry-dbid-42037045-38c2-4971-95b3-1c6caa2fdedc")}catch{}})();const k={class:"error"},I={class:"inner-content"},x=g({__name:"Error",setup(o){const r=b(),{result:e}=_(f),c=()=>{const{status:s}=r.params;switch(s){case"404":return{status:s,message:"Page not found."};case"403":return{status:s,message:"Access denied. Please contact your administrator."};default:return{status:"500",message:"An unknown error ocurred. Please try again or contact support."}}};return(s,B)=>(n(),h("div",null,[a("div",k,[t(e)?(n(),d(y,{key:0,"main-color":t(e).mainColor,theme:t(e).theme,"font-family":t(e).fontFamily,style:{height:"100vh"}},{default:v(()=>{var i,m;return[t(e)?(n(),d(p,{key:0,"brand-name":((i=t(e))==null?void 0:i.brandName)||((m=t(e))==null?void 0:m.name),"logo-url":t(e).logoUrl},null,8,["brand-name","logo-url"])):l("",!0),a("div",I,[a("h1",null,u(c().status),1),a("p",null,u(c().message),1)])]}),_:1},8,["main-color","theme","font-family"])):l("",!0)])]))}});const D=w(x,[["__scopeId","data-v-befb94cf"]]);export{D as default};
//# sourceMappingURL=Error.5db25e19.js.map
