import{d as r,b as n,ev as t,dp as s,e as o,ez as d,ex as i,v as c}from"./outputWidgets.0a8e4948.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="4b244d00-b68a-4aa4-a0b3-b8b0e536e9e8",a._sentryDebugIdIdentifier="sentry-dbid-4b244d00-b68a-4aa4-a0b3-b8b0e536e9e8")}catch{}})();const u={key:0,class:"canvas-container"},v={class:"canvas-content"},_={class:"canvas-absolute"},f={class:"canvas-footer"},b={key:1,class:"content-container"},y={key:0,class:"content-footer"},p=r({__name:"BaseLayout",props:{fullCanvas:{type:Boolean},noMargins:{type:Boolean}},setup(a){return(e,l)=>(n(),t("div",{class:d(["base-layout",{"full-canvas":e.fullCanvas}])},[s(e.$slots,"navbar",{},void 0,!0),o("div",{class:d(["middle-layout",{"full-canvas":e.fullCanvas}])},[s(e.$slots,"sidebar",{},void 0,!0),e.fullCanvas?(n(),t("div",u,[o("div",v,[o("div",_,[s(e.$slots,"content",{},void 0,!0)])]),o("div",f,[s(e.$slots,"footer",{},void 0,!0)])])):(n(),t("div",b,[o("div",{class:d(["content-layout",{"no-margins":e.noMargins}])},[s(e.$slots,"content",{},void 0,!0)],2)]))],2),e.fullCanvas?i("",!0):(n(),t("div",y,[s(e.$slots,"footer",{},void 0,!0)]))],2))}});const g=c(p,[["__scopeId","data-v-393a4c0b"]]);export{g as B};
//# sourceMappingURL=BaseLayout.41f796b7.js.map
