import"./outputWidgets.0a8e4948.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="c2c82047-9f84-4dd1-be9d-eb68d22417c3",e._sentryDebugIdIdentifier="sentry-dbid-c2c82047-9f84-4dd1-be9d-eb68d22417c3")}catch{}})();function i(e){return e.charAt(0).toUpperCase()+e.slice(1)}function l(e,n,a=!1,t=!0){const o=(t?e.toLocaleLowerCase():e).normalize("NFD").replace(/[\u0300-\u036f]/g,"").replace(/[^a-zA-Z0-9]/g,"_"),s=a?o:o.replace(/_+/g,"_");return n?s:s.replace(/_$/,"")}function u(e){var c;const a=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),t=/[a-z0-9]+/g,r=a.match(t);return(c=r==null?void 0:r.join("-"))!=null?c:""}function f(e){try{return{valid:!0,parsed:JSON.parse(e)}}catch(n){return{valid:!1,message:n.message}}}export{u as a,i as c,l as n,f as v};
//# sourceMappingURL=string.349cf797.js.map
