import"./outputWidgets.0a8e4948.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="fb1f6cc6-7811-493e-94c5-992448cf35b3",e._sentryDebugIdIdentifier="sentry-dbid-fb1f6cc6-7811-493e-94c5-992448cf35b3")}catch{}})();const f=e=>{try{return new URL(e),!0}catch{return!1}};export{f as i};
//# sourceMappingURL=url.5c05e609.js.map
