import{B as s}from"./Base.dda5d58b.js";import{A as o}from"./Link.6650ff19.js";import{A as r}from"./Paragraph.b4aaf7da.js";import{A as a}from"./Text.ec9c769b.js";import{A as i}from"./Title.ca8d43a3.js";import{T as e}from"./Typography.fd999a5c.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="bf4a4f34-f001-4e04-96e0-0732c6280051",n._sentryDebugIdIdentifier="sentry-dbid-bf4a4f34-f001-4e04-96e0-0732c6280051")}catch{}})();e.Text=a;e.Title=i;e.Paragraph=r;e.Link=o;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,a),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,r),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.c3402215.js.map
