import{eN as t,eO as r}from"./outputWidgets.0a8e4948.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="279b11b0-4bbc-47cc-bf08-0d0415374492",e._sentryDebugIdIdentifier="sentry-dbid-279b11b0-4bbc-47cc-bf08-0d0415374492")}catch{}})();function s(e,n){return t(1,arguments),r(e,Date.now(),n)}export{s as f};
//# sourceMappingURL=index.b9c8498e.js.map
