import{C as t,A as m}from"./CollapsePanel.59258ae1.js";import{F as n}from"./Form.c559c050.js";import{aM as i,co as r}from"./outputWidgets.0a8e4948.js";import{T as o,A as s}from"./Timeline.bd3fc2e4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="b1a7b4f1-843e-4d7c-86c9-075f4aee4d65",e._sentryDebugIdIdentifier="sentry-dbid-b1a7b4f1-843e-4d7c-86c9-075f4aee4d65")}catch{}})();t.Panel=m;t.install=function(e){return e.component(t.name,t),e.component(m.name,m),e};n.useInjectFormItemContext=i;n.ItemRest=r;n.install=function(e){return e.component(n.name,n),e.component(n.Item.name,n.Item),e.component(r.name,r),e};o.Item=s;o.install=function(e){return e.component(o.name,o),e.component(s.name,s),e};
//# sourceMappingURL=index.f4e17bed.js.map
