import{r as a,w as r}from"./runnerData.e96f67ef.js";import"./outputWidgets.0a8e4948.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="04cc9a54-14ea-4e2e-b029-bdb538bf0d09",t._sentryDebugIdIdentifier="sentry-dbid-04cc9a54-14ea-4e2e-b029-bdb538bf0d09")}catch{}})();async function f(t){const e=await fetch(`/_pages/${t}`);if(e.status==404)return null;if(!e.ok)throw new Error(await e.text());const{form:n}=await e.json();return n?a(n):null}async function u(){const t=await fetch("/_workspace");if(t.status!=200)return r({});const e=await t.json();return r(e)}export{f,u as g};
//# sourceMappingURL=api.2af17107.js.map
