import{V as s,f as d,Q as p}from"./outputWidgets.0a8e4948.js";import{B as f,b as i}from"./Base.dda5d58b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="f27039d5-e157-49fe-a49b-742fdbd0cf09",e._sentryDebugIdIdentifier="sentry-dbid-f27039d5-e157-49fe-a49b-742fdbd0cf09")}catch{}})();const y=()=>p(i(),["component"]),a=(e,r)=>{let{slots:t,attrs:o}=r;const n=s(s(s({},e),{component:"div"}),o);return d(f,n,t)};a.displayName="ATypographyParagraph";a.inheritAttrs=!1;a.props=y();const g=a;export{g as A};
//# sourceMappingURL=Paragraph.b4aaf7da.js.map
