import{V as a}from"./outputWidgets.0a8e4948.js";import{c as s,d as i}from"./index.1381e52f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="99232c9c-5ff6-423f-9242-fd48286fc5fa",e._sentryDebugIdIdentifier="sentry-dbid-99232c9c-5ff6-423f-9242-fd48286fc5fa")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:d,TimePicker:m,QuarterPicker:o,RangePicker:c}=s(i),g=a(n,{WeekPicker:r,MonthPicker:t,YearPicker:d,RangePicker:c,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(c.name,c),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{g as D,t as M,o as Q,c as R,r as W};
//# sourceMappingURL=dayjs.fcb78c8c.js.map
