import{ac as c,V as t,Q as r,f}from"./outputWidgets.0a8e4948.js";import{B as p,b as l}from"./Base.dda5d58b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="bac6514d-ef64-4595-b1e3-05bf53aa4c9c",e._sentryDebugIdIdentifier="sentry-dbid-bac6514d-ef64-4595-b1e3-05bf53aa4c9c")}catch{}})();const b=()=>t(t({},r(l(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),o=(e,s)=>{let{slots:a,attrs:d}=s;const{ellipsis:n}=e;c();const i=t(t(t({},e),{ellipsis:n&&typeof n=="object"?r(n,["expandable","rows"]):n,component:"span"}),d);return f(p,i,a)};o.displayName="ATypographyText";o.inheritAttrs=!1;o.props=b();const g=o;export{g as A};
//# sourceMappingURL=Text.ec9c769b.js.map
