import"./outputWidgets.0a8e4948.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c64add6b-a8b0-47aa-827e-0e33f7a5baba",e._sentryDebugIdIdentifier="sentry-dbid-c64add6b-a8b0-47aa-827e-0e33f7a5baba")}catch{}})();function a(e,t){return e.toLocaleString(void 0,{hour12:!1,timeZoneName:"short",day:"2-digit",month:"2-digit",year:"numeric",hour:"2-digit",minute:"2-digit",second:"2-digit",weekday:"long",...t})}export{a as g};
//# sourceMappingURL=datetime.51e47906.js.map
