import{d as m,eB as c,u as e,b as d,c as u,ev as y,f as o,w as a,bv as _,ar as p,ex as g,e as b,eD as x}from"./outputWidgets.0a8e4948.js";import"./router.a730a2c1.js";import"./index.fea4a6f4.js";import{O as w}from"./organization.9a1833bb.js";import{a as k}from"./asyncComputed.059a4705.js";import{A}from"./Title.ca8d43a3.js";import{A as B}from"./index.2673874d.js";import{A as h}from"./index.6be6239e.js";import{A as C}from"./Text.ec9c769b.js";import{C as v}from"./Card.34fc0534.js";import"./Form.c559c050.js";import"./hasIn.8bcc6abb.js";import"./index.cf4c23b9.js";import"./record.68d70ea4.js";import"./pubsub.dcb12b9f.js";import"./Base.dda5d58b.js";import"./Typography.fd999a5c.js";import"./TabPane.4ede097c.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="4dd1f178-9d0b-4692-894f-80274580a0ae",t._sentryDebugIdIdentifier="sentry-dbid-4dd1f178-9d0b-4692-894f-80274580a0ae")}catch{}})();const D={key:1},I={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},W=m({__name:"Billing",setup(t){const n=c().params.organizationId,{loading:l,result:f}=k(()=>w.get(n));return(z,N)=>e(l)?(d(),u(e(_),{key:0})):(d(),y("div",D,[o(e(B),{justify:"space-between",align:"center"},{default:a(()=>[o(e(A),{level:3},{default:a(()=>[p("Current plan")]),_:1}),g("",!0)]),_:1}),o(e(h),{style:{"margin-top":"0"}}),o(e(v),{style:{width:"300px"}},{default:a(()=>{var i,s;return[o(e(C),{type:"secondary"},{default:a(()=>[p("Plan")]),_:1}),b("div",I,x((s=(i=e(f))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{W as default};
//# sourceMappingURL=Billing.fafebe1d.js.map
