import{g as c}from"./api.2af17107.js";import{P as f}from"./Passwordless.69343137.js";import{a as m}from"./asyncComputed.059a4705.js";import{W as p}from"./WidgetsFrame.64d79499.js";import{d as u,eA as l,eB as _,b as i,ev as y,e as g,u as s,c as b,w as h,ex as w,f as v,v as k}from"./outputWidgets.0a8e4948.js";import"./runnerData.e96f67ef.js";import"./url.5c05e609.js";import"./index.14897ab9.js";import"./pubsub.dcb12b9f.js";import"./icons.b13f0b09.js";import"./CircularLoading.68854f75.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9068fe17-7fce-42af-9eef-1409e22a8e4b",e._sentryDebugIdIdentifier="sentry-dbid-9068fe17-7fce-42af-9eef-1409e22a8e4b")}catch{}})();const x={class:"login"},I=u({__name:"Login",setup(e){const t=l(),a=_(),{result:o}=m(c),d=()=>{const{redirect:r,...n}=a.query;if(r){t.push({path:r,query:n,params:a.params});return}t.push({name:"playerKanban",query:n})};return(r,n)=>(i(),y("div",null,[g("div",x,[s(o)?(i(),b(p,{key:0,"main-color":s(o).mainColor,theme:s(o).theme,"font-family":s(o).fontFamily,style:{width:"100vw"}},{default:h(()=>[v(f,{onDone:d})]),_:1},8,["main-color","theme","font-family"])):w("",!0)])]))}});const R=k(I,[["__scopeId","data-v-33714d9d"]]);export{R as default};
//# sourceMappingURL=Login.300d8f32.js.map
